@@ -98,12 +98,13 @@ def get_session(**kwargs):
                       numerical value indicating some amount (or fraction)
                       of seconds or 0 for no timeout. (optional, defaults
                       to 0)
-    :param verify: The verification arguments to pass to requests. These are of
-                   the same form as requests expects, so True or False to
-                   verify (or not) against system certificates or a path to a
-                   bundle or CA certs to check against or None for requests to
-                   attempt to locate and use certificates. (optional, defaults
-                   to True)
+    :param bool insecure: Should request be verified or not
+                      (optional, defaults to False)
+    :param union(string,tuple) ca_file: A client certificate to pass to
+                 requests. These are of the same form as requests expects.
+                 Either a single filename containing both the certificate
+                 and key or a tuple containing the path to the certificate
+                 then a path to the key. (optional)
     :param bool reauthenticate: Should reauthenticate if token expires
                         (optional, defaults to True)
     :return: session instance
@@ -138,7 +139,8 @@ def get_session(**kwargs):
                            app_version=ma_version.version_string,
                            user_agent='monasca-agent',
                            timeout=kwargs.get('keystone_timeout', None),
-                           verify=kwargs.get('verify', True))
+                           verify=not kwargs.get('insecure', False),
+                           cert=kwargs.get('ca_file', None))
     return sess
 
 
@@ -221,7 +223,8 @@ def get_args(config):
         'endpoint_type': config.get('endpoint_type', _DEFAULT_ENDPOINT_TYPE),
         'region_name': config.get('region_name', None),
         'keystone_timeout': config.get('keystone_timeout', None),
-        'verify': False if config.get('insecure') else config.get('ca_file', None),
+        'insecure': config.get('insecure', False),
+        'ca_file': config.get('ca_file', None),
         'reauthenticate': config.get('reauthenticate', True)
     }
     clean_args = _sanitize_args(raw_args)
